@@ -388,7 +388,8 @@ if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
        --rootdir "$VROOTDIR" --hostname "$VHOST" --interface "$INTERFACE:$IP" \
        -- -d "$DIST" -m "$MIRROR" \
        -- $ARCH_ARGUMENT \
-        --include="$INSTALL_PACKAGES" --exclude="$REMOVE_PACKAGES"
+       --include="$INSTALL_PACKAGES" --exclude="$REMOVE_PACKAGES" \
+       --resolve-deps
   then
     echo "${0##*/}: error: vserver-build failure. Cannot continue."
     exit 1
